@@ -40,11 +40,11 @@ HELP_CONTENT = """
         
         -v          : set the version of the project
         
-        -p          : set the project name. if this parameter is null, will use file name as project name
+        -n          : set the project name. if this parameter is null, will use file name as project name
         
         -j          : project id.
         
-        -h          : report output path. Default path is current working directory.
+        -p          : report output path. Default path is current working directory.
         
 file + version -> create new project, name by file.【if duplicate name project exist, will update the project】
 
@@ -61,11 +61,10 @@ project_id -> scan existing project.
 
         -r [csv|pdf|csv-remediation|pdf-remediation]: download scan report
         
-        -h          : report output path. Default path is current working directory.
+        -p          : report output path. Default path is current working directory.
         
         -b          : trigger source code scan with bom-detect. Otherwise, upload file and remotely trigger build and scan.
          
-        -h          : report output path. Default path is current working directory.
 ## List user projects
 - scantist_cmd -l
 
@@ -98,14 +97,13 @@ def main():
     try:
         opts, args = getopt.getopt(
             argv,
-            "hblt:f:v:r:j:z:p:h",
+            "hblt:f:v:r:j:n:p:b:",
             [
                 "scan_type=",
                 "file_path=",
                 "version=",
                 "report_format=",
                 "project_id=",
-                "zip_paths=",
                 "project_name=",
                 "report_path=",
                 "bom_detect=",
@@ -141,11 +139,11 @@ def main():
             report_format = arg.split("-")[0]
             if len(arg.split("-")) > 1:
                 is_generate_remediation_report = True
-        elif opt in ("-h", "--report_path"):
+        elif opt in ("-p", "--report_path"):
             report_path = arg
         elif opt in ("-j", "--project_id"):
             project_id = arg
-        elif opt in ("-p", "--project_name"):
+        elif opt in ("-n", "--project_name"):
             project_name = arg
         elif opt in ("-b", "--bom_detect"):
             is_bom_detect = True
@@ -271,4 +269,7 @@ def main():
             logger.info(f"Generalize report for scan {scan_id}")
             get_report(scan_id, apikey, baseurl, report_format, output_folder)
 
-    get_scan_summary(scan_id, apikey, baseurl)
+    if status == "finished":
+        get_scan_summary(scan_id, apikey, baseurl)
+    elif status == "failed":
+        logger.info(f"Scan Failed! Please check details on Scantist website")
